@@ -92,6 +92,7 @@ class ClientSettings(TypedDict, total=False):
 
 class WebRtcStreamerState(NamedTuple):
     playing: bool
+    signalling: bool
 
 
 class WebRtcStreamerContext(Generic[VideoProcessorT, AudioProcessorT]):
@@ -157,6 +158,7 @@ def webrtc_streamer(
     key: str,
     mode: WebRtcMode = WebRtcMode.SENDRECV,
     client_settings: Optional[ClientSettings] = None,
+    desired_playing_state: Optional[bool] = None,
     player_factory: Optional[MediaPlayerFactory] = None,
     in_recorder_factory: Optional[MediaRecorderFactory] = None,
     out_recorder_factory: Optional[MediaRecorderFactory] = None,
@@ -181,6 +183,7 @@ def webrtc_streamer(
     key: str,
     mode: WebRtcMode = WebRtcMode.SENDRECV,
     client_settings: Optional[ClientSettings] = None,
+    desired_playing_state: Optional[bool] = None,
     player_factory: Optional[MediaPlayerFactory] = None,
     in_recorder_factory: Optional[MediaRecorderFactory] = None,
     out_recorder_factory: Optional[MediaRecorderFactory] = None,
@@ -201,6 +204,7 @@ def webrtc_streamer(
     key: str,
     mode: WebRtcMode = WebRtcMode.SENDRECV,
     client_settings: Optional[ClientSettings] = None,
+    desired_playing_state: Optional[bool] = None,
     player_factory: Optional[MediaPlayerFactory] = None,
     in_recorder_factory: Optional[MediaRecorderFactory] = None,
     out_recorder_factory: Optional[MediaRecorderFactory] = None,
@@ -221,6 +225,7 @@ def webrtc_streamer(
     key: str,
     mode: WebRtcMode = WebRtcMode.SENDRECV,
     client_settings: Optional[ClientSettings] = None,
+    desired_playing_state: Optional[bool] = None,
     player_factory: Optional[MediaPlayerFactory] = None,
     in_recorder_factory: Optional[MediaRecorderFactory] = None,
     out_recorder_factory: Optional[MediaRecorderFactory] = None,
@@ -240,6 +245,7 @@ def webrtc_streamer(
     key: str,
     mode: WebRtcMode = WebRtcMode.SENDRECV,
     client_settings: Optional[ClientSettings] = None,
+    desired_playing_state: Optional[bool] = None,
     player_factory: Optional[MediaPlayerFactory] = None,
     in_recorder_factory: Optional[MediaRecorderFactory] = None,
     out_recorder_factory: Optional[MediaRecorderFactory] = None,
@@ -274,6 +280,7 @@ def webrtc_streamer(
         sdp_answer_json=sdp_answer_json,
         mode=mode.name,
         settings=client_settings,
+        desired_playing_state=desired_playing_state,
     )
 
     playing = False
@@ -282,8 +289,13 @@ def webrtc_streamer(
         playing = component_value.get("playing", False)
         sdp_offer = component_value.get("sdpOffer")
 
-    if webrtc_worker and not playing:
-        LOGGER.debug("Unset the worker because the frontend state is not playing.")
+    signalling = sdp_offer is not None
+
+    if webrtc_worker and not playing and not signalling:
+        LOGGER.debug(
+            "Unset the worker because the frontend state is "
+            "neither playing nor signalling."
+        )
         webrtc_worker.stop()
         _unset_webrtc_worker(key)
         webrtc_worker = None
@@ -313,7 +325,7 @@ def webrtc_streamer(
         st.experimental_rerun()
 
     ctx = WebRtcStreamerContext(
-        state=WebRtcStreamerState(playing=playing),
+        state=WebRtcStreamerState(playing=playing, signalling=signalling),
         worker=webrtc_worker,
     )
 
